@@ -21,6 +21,7 @@
 #include <Akonadi/TagFetchScope>
 
 #include <KConfigGroup>
+#include <KLocalizedString>
 #include <KSharedConfig>
 
 Q_DECLARE_METATYPE(Akonadi::NotificationSubscriber)
@@ -73,22 +74,22 @@ QString toString(const QSet<Akonadi::Monitor::Type> &set)
     for (const auto &v : set) {
         switch (v) {
         case Akonadi::Monitor::Items:
-            rv << QStringLiteral("Items");
+            rv << i18n("Items");
             break;
         case Akonadi::Monitor::Collections:
-            rv << QStringLiteral("Collections");
+            rv << i18n("Collections");
             break;
         case Akonadi::Monitor::Tags:
-            rv << QStringLiteral("Tags");
+            rv << i18n("Tags");
             break;
         case Akonadi::Monitor::Relations:
-            rv << QStringLiteral("Relations");
+            rv << i18n("Relations");
             break;
         case Akonadi::Monitor::Subscribers:
-            rv << QStringLiteral("Subscribers");
+            rv << i18n("Subscribers");
             break;
         case Akonadi::Monitor::Notifications:
-            rv << QStringLiteral("Notification");
+            rv << i18n("Notification");
             break;
         }
     }
@@ -97,28 +98,28 @@ QString toString(const QSet<Akonadi::Monitor::Type> &set)
 
 void MonitorsWidget::populateCollectionFetchScope(QStandardItem *parent, const Akonadi::CollectionFetchScope &cfs)
 {
-    appendRow(parent, QStringLiteral("List Filter"), toString(cfs.listFilter()));
-    appendRow(parent, QStringLiteral("Include Statistics"), toString(cfs.includeStatistics()));
-    appendRow(parent, QStringLiteral("Resource"), cfs.resource());
-    appendRow(parent, QStringLiteral("Content MimeTypes"), toString(static_cast<QList<QString>>(cfs.contentMimeTypes())));
-    appendRow(parent, QStringLiteral("Ancestor Retrieval"), toString(cfs.ancestorRetrieval()));
+    appendRow(parent, i18n("List Filter"), toString(cfs.listFilter()));
+    appendRow(parent, i18n("Include Statistics"), toString(cfs.includeStatistics()));
+    appendRow(parent, i18n("Resource"), cfs.resource());
+    appendRow(parent, i18n("Content MimeTypes"), toString(static_cast<QList<QString>>(cfs.contentMimeTypes())));
+    appendRow(parent, i18n("Ancestor Retrieval"), toString(cfs.ancestorRetrieval()));
 
     const auto ancestorFs = cfs.ancestorFetchScope();
     if (!ancestorFs.isEmpty()) {
-        auto ancestorItem = new QStandardItem(QStringLiteral("Ancestor Fetch Scope"));
+        auto ancestorItem = new QStandardItem(i18n("Ancestor Fetch Scope"));
         populateCollectionFetchScope(ancestorItem, cfs.ancestorFetchScope());
         parent->appendRow(ancestorItem);
     }
 
-    appendRow(parent, QStringLiteral("Attributes"), toString(cfs.attributes()));
-    appendRow(parent, QStringLiteral("Fetch ID Only"), toString(cfs.fetchIdOnly()));
-    appendRow(parent, QStringLiteral("Ignore Retrieval Error"), toString(cfs.ignoreRetrievalErrors()));
+    appendRow(parent, i18n("Attributes"), toString(cfs.attributes()));
+    appendRow(parent, i18n("Fetch ID Only"), toString(cfs.fetchIdOnly()));
+    appendRow(parent, i18n("Ignore Retrieval Error"), toString(cfs.ignoreRetrievalErrors()));
 }
 
 void MonitorsWidget::populateTagFetchScope(QStandardItem *parent, const Akonadi::TagFetchScope &tfs)
 {
-    appendRow(parent, QStringLiteral("Attributes"), toString(tfs.attributes()));
-    appendRow(parent, QStringLiteral("Fetch ID Only"), toString(tfs.fetchIdOnly()));
+    appendRow(parent, i18n("Attributes"), toString(tfs.attributes()));
+    appendRow(parent, i18n("Fetch ID Only"), toString(tfs.fetchIdOnly()));
 }
 
 void MonitorsWidget::onSubscriberSelected(const QModelIndex &index)
@@ -126,7 +127,7 @@ void MonitorsWidget::onSubscriberSelected(const QModelIndex &index)
     auto model = qobject_cast<QStandardItemModel *>(mSubscriberView->model());
     const auto state = mSubscriberView->header()->saveState();
     model->clear();
-    model->setHorizontalHeaderLabels({QStringLiteral("Properties"), QStringLiteral("Values")});
+    model->setHorizontalHeaderLabels({i18n("Properties"), i18n("Values")});
     mSubscriberView->header()->restoreState(state);
 
     const auto subscriber = index.data(MonitorsModel::SubscriberRole).value<Akonadi::NotificationSubscriber>();
@@ -134,39 +135,39 @@ void MonitorsWidget::onSubscriberSelected(const QModelIndex &index)
         return;
     }
 
-    appendRow(model, QStringLiteral("Subscriber"), QString::fromUtf8(subscriber.subscriber()));
-    appendRow(model, QStringLiteral("Session ID"), QString::fromUtf8(subscriber.sessionId()));
-    appendRow(model, QStringLiteral("Monitored Collections:"), toString(subscriber.monitoredCollections()));
-    appendRow(model, QStringLiteral("Monitored Items:"), toString(subscriber.monitoredItems()));
-    appendRow(model, QStringLiteral("Monitored Tags:"), toString(subscriber.monitoredTags()));
-    appendRow(model, QStringLiteral("Monitored Types:"), toString(subscriber.monitoredTypes()));
-    appendRow(model, QStringLiteral("Monitored Mime Types:"), toString(subscriber.monitoredMimeTypes()));
-    appendRow(model, QStringLiteral("Monitored Resources:"), toString(subscriber.monitoredResources()));
-    appendRow(model, QStringLiteral("Ignored Sessions:"), toString(subscriber.ignoredSessions()));
-    appendRow(model, QStringLiteral("All Monitored:"), toString(subscriber.isAllMonitored()));
-    appendRow(model, QStringLiteral("Is Exclusive:"), toString(subscriber.isExclusive()));
+    appendRow(model, i18n("Subscriber"), QString::fromUtf8(subscriber.subscriber()));
+    appendRow(model, i18n("Session ID"), QString::fromUtf8(subscriber.sessionId()));
+    appendRow(model, i18n("Monitored Collections:"), toString(subscriber.monitoredCollections()));
+    appendRow(model, i18n("Monitored Items:"), toString(subscriber.monitoredItems()));
+    appendRow(model, i18n("Monitored Tags:"), toString(subscriber.monitoredTags()));
+    appendRow(model, i18n("Monitored Types:"), toString(subscriber.monitoredTypes()));
+    appendRow(model, i18n("Monitored Mime Types:"), toString(subscriber.monitoredMimeTypes()));
+    appendRow(model, i18n("Monitored Resources:"), toString(subscriber.monitoredResources()));
+    appendRow(model, i18n("Ignored Sessions:"), toString(subscriber.ignoredSessions()));
+    appendRow(model, i18n("All Monitored:"), toString(subscriber.isAllMonitored()));
+    appendRow(model, i18n("Is Exclusive:"), toString(subscriber.isExclusive()));
 
-    auto ifsItem = new QStandardItem(QStringLiteral("Item Fetch Scope"));
+    auto ifsItem = new QStandardItem(i18n("Item Fetch Scope"));
     const auto ifs = subscriber.itemFetchScope();
-    appendRow(ifsItem, QStringLiteral("Payload Parts"), toString(ifs.payloadParts()));
-    appendRow(ifsItem, QStringLiteral("Full Paryload"), toString(ifs.fullPayload()));
-    appendRow(ifsItem, QStringLiteral("Attributes"), toString(ifs.attributes()));
-    appendRow(ifsItem, QStringLiteral("All Attributes"), toString(ifs.allAttributes()));
-    appendRow(ifsItem, QStringLiteral("Cache only"), toString(ifs.cacheOnly()));
-    appendRow(ifsItem, QStringLiteral("Check for Cached Payloads Parts Only"), toString(ifs.checkForCachedPayloadPartsOnly()));
-    appendRow(ifsItem, QStringLiteral("Ancestor Retrieval"), toString(ifs.ancestorRetrieval()));
-    appendRow(ifsItem, QStringLiteral("Fetch mtime"), toString(ifs.fetchModificationTime()));
-    appendRow(ifsItem, QStringLiteral("Fetch GID"), toString(ifs.fetchGid()));
-    appendRow(ifsItem, QStringLiteral("Ignore Retrieval Errors"), toString(ifs.ignoreRetrievalErrors()));
-    appendRow(ifsItem, QStringLiteral("Fetch Change Since"), toString(ifs.fetchChangedSince()));
-    appendRow(ifsItem, QStringLiteral("Fetch RID"), toString(ifs.fetchRemoteIdentification()));
-    appendRow(ifsItem, QStringLiteral("Fetch Tags"), toString(ifs.fetchTags()));
+    appendRow(ifsItem, i18n("Payload Parts"), toString(ifs.payloadParts()));
+    appendRow(ifsItem, i18n("Full Paryload"), toString(ifs.fullPayload()));
+    appendRow(ifsItem, i18n("Attributes"), toString(ifs.attributes()));
+    appendRow(ifsItem, i18n("All Attributes"), toString(ifs.allAttributes()));
+    appendRow(ifsItem, i18n("Cache only"), toString(ifs.cacheOnly()));
+    appendRow(ifsItem, i18n("Check for Cached Payloads Parts Only"), toString(ifs.checkForCachedPayloadPartsOnly()));
+    appendRow(ifsItem, i18n("Ancestor Retrieval"), toString(ifs.ancestorRetrieval()));
+    appendRow(ifsItem, i18n("Fetch mtime"), toString(ifs.fetchModificationTime()));
+    appendRow(ifsItem, i18n("Fetch GID"), toString(ifs.fetchGid()));
+    appendRow(ifsItem, i18n("Ignore Retrieval Errors"), toString(ifs.ignoreRetrievalErrors()));
+    appendRow(ifsItem, i18n("Fetch Change Since"), toString(ifs.fetchChangedSince()));
+    appendRow(ifsItem, i18n("Fetch RID"), toString(ifs.fetchRemoteIdentification()));
+    appendRow(ifsItem, i18n("Fetch Tags"), toString(ifs.fetchTags()));
 
     const auto cfs = subscriber.collectionFetchScope();
-    auto cfsItem = new QStandardItem(QStringLiteral("Collection Fetch Scope"));
+    auto cfsItem = new QStandardItem(i18n("Collection Fetch Scope"));
     populateCollectionFetchScope(cfsItem, cfs);
 
-    auto tagScope = new QStandardItem(QStringLiteral("Tag Fetch Scope"));
+    auto tagScope = new QStandardItem(i18n("Tag Fetch Scope"));
     populateTagFetchScope(tagScope, subscriber.tagFetchScope());
     model->appendRow(tagScope);
 
